add_paren: Concatenate all elements and surround the result by ()

Description Usage Arguments Value Examples

Description

Concatenate the elements in x into a string and surround the result by parentheses. This does not add single quote to each element

Usage

1

Arguments

x

vector

Value

a character string

Examples

1

taekyunk/paren documentation built on May 14, 2019, 11:29 a.m.